==> talk2-0.2.6.jar: public/js/test/js/cljs-runtime/deercreeklabs.lancaster.sub.js <==
goog.provide('deercreeklabs.lancaster.sub');
deercreeklabs.lancaster.sub.path_type_STAR_ = (function deercreeklabs$lancaster$sub$path_type_STAR_(path_entry){
if((path_entry instanceof cljs.core.Keyword)){
return new cljs.core.Keyword(null,"keyword","keyword",811389747);
} else {
if(typeof path_entry === 'string'){
return new cljs.core.Keyword(null,"string","string",-1989541586);
} else {
if(cljs.core.int_QMARK_(path_entry)){
return new cljs.core.Keyword(null,"int","int",-1741416922);
} else {
return null;

}
}
}
});
deercreeklabs.lancaster.sub.__GT_matching_union_child_schema = (function deercreeklabs$lancaster$sub$__GT_matching_union_child_schema(schema__$1,edn_schema,path_entry){
var path_type = deercreeklabs.lancaster.sub.path_type_STAR_(path_entry);
var ret = cljs.core.some((function (p__52713){
var vec__52714 = p__52713;
var i = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__52714,(0),null);
var sub = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__52714,(1),null);
var avro_type = deercreeklabs.lancaster.utils.avro_type_dispatch_lt(sub);
var G__52718 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [avro_type,path_type], null);
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"record","record",-779106859),new cljs.core.Keyword(null,"keyword","keyword",811389747)], null),G__52718)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i),path_entry);
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"map","map",1371690461),new cljs.core.Keyword(null,"string","string",-1989541586)], null),G__52718)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"array","array",-2080713842),new cljs.core.Keyword(null,"int","int",-1741416922)], null),G__52718)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"logical-type","logical-type",-1509387615),avro_type)){
var temp__5804__auto__ = new cljs.core.Keyword(null,"k->child-edn-schema","k->child-edn-schema",-999586031).cljs$core$IFn$_invoke$arity$1(edn_schema);
if(cljs.core.truth_(temp__5804__auto__)){
var __GT_ces = temp__5804__auto__;
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
return null;
}
} else {
return null;
}

}
}
}
}),cljs.core.map_indexed.cljs$core$IFn$_invoke$arity$2(cljs.core.vector,edn_schema));
if(cljs.core.truth_(ret)){
return ret;
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["No matching schema in union for ","key `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(path_entry),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"schema","schema",-1582001791),schema__$1,new cljs.core.Keyword(null,"k","k",-2146297393),path_entry], null));
}
});
deercreeklabs.lancaster.sub.schema_at_path = (function deercreeklabs$lancaster$sub$schema_at_path(var_args){
var G__52722 = arguments.length;
switch (G__52722) {
case 2:
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$2 = (function (schema__$1,path){
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3(schema__$1,path,null);
}));

(deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3 = (function (schema__$1,path,p__52726){
while(true){
var map__52727 = p__52726;
var map__52727__$1 = cljs.core.__destructure_map(map__52727);
var opts = map__52727__$1;
var branches_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52727__$1,new cljs.core.Keyword(null,"branches?","branches?",-1426607703));
var child = cljs.core.first(path);
if(cljs.core.not(child)){
return schema__$1;
} else {
var edn_schema = new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255).cljs$core$IFn$_invoke$arity$1(schema__$1);
var child_schema = (function (){var G__52728 = deercreeklabs.lancaster.utils.avro_type_dispatch_lt(edn_schema);
var G__52728__$1 = (((G__52728 instanceof cljs.core.Keyword))?G__52728.fqn:null);
switch (G__52728__$1) {
case "record":
return deercreeklabs.lancaster.utils.child_schema(schema__$1,child);

break;
case "map":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
case "array":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
case "union":
if(cljs.core.truth_((function (){var and__5043__auto__ = branches_QMARK_;
if(cljs.core.truth_(and__5043__auto__)){
return cljs.core.int_QMARK_(child);
} else {
return and__5043__auto__;
}
})())){
return deercreeklabs.lancaster.utils.child_schema(schema__$1,child);
} else {
return deercreeklabs.lancaster.sub.__GT_matching_union_child_schema(schema__$1,edn_schema,child);
}

break;
case "logical-type":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
default:
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2("Can't get schema at path for non-container type.",new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"schema","schema",-1582001791),schema__$1,new cljs.core.Keyword(null,"path","path",-188191168),path], null));

}
})();
var G__52734 = child_schema;
var G__52735 = cljs.core.rest(path);
var G__52736 = opts;
schema__$1 = G__52734;
path = G__52735;
p__52726 = G__52736;
continue;
}
break;
}
}));

(deercreeklabs.lancaster.sub.schema_at_path.cljs$lang$maxFixedArity = 3);

deercreeklabs.lancaster.sub.member_schemas = (function deercreeklabs$lancaster$sub$member_schemas(schema__$1){
var map__52729 = schema__$1;
var map__52729__$1 = cljs.core.__destructure_map(map__52729);
var child_info = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52729__$1,new cljs.core.Keyword(null,"child-info","child-info",1041367133));
var edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52729__$1,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255));
var avro_type = deercreeklabs.lancaster.utils.get_avro_type(edn_schema);
var _ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"union","union",2142937499),avro_type))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The argument to `member-schemas` must be ","a union schema. Got type `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(avro_type),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"schema","schema",-1582001791),schema__$1,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
return cljs.core.mapv.cljs$core$IFn$_invoke$arity$2((function (sub){
if((sub instanceof cljs.core.Keyword)){
return sub.cljs$core$IFn$_invoke$arity$1(cljs.core.deref(deercreeklabs.lancaster.utils._STAR___INTERNAL__name__GT_schema));
} else {
return sub;
}
}),child_info);
});
deercreeklabs.lancaster.sub.member_schema_at_branch = (function deercreeklabs$lancaster$sub$member_schema_at_branch(schema__$1,branch_index){
var map__52730 = schema__$1;
var map__52730__$1 = cljs.core.__destructure_map(map__52730);
var edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52730__$1,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255));
var name__GT_edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52730__$1,new cljs.core.Keyword(null,"name->edn-schema","name->edn-schema",-1518578869));
var avro_type = deercreeklabs.lancaster.utils.get_avro_type(edn_schema);
var _ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"union","union",2142937499),avro_type))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `schema` argument to `member-schema-at-branch` ","must be a union schema. Got type: `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(avro_type),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
var ___$1 = ((cljs.core.int_QMARK_(branch_index))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `branch-index` argument to `member-schema-at-branch` ","must be an integer. Got: `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(branch_index),"`."].join(''),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"branch-index","branch-index",-605664862),branch_index,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
var ___$2 = (((((branch_index >= cljs.core.count(edn_schema))) || ((branch_index < (0)))))?(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `branch-index` argument (`",cljs.core.str.cljs$core$IFn$_invoke$arity$1(branch_index),"`) ","to `member-schema-at-branch` is out of range. Length of ","union schema is ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.count(edn_schema)),"."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"branch-index","branch-index",-605664862),branch_index], null))})():null);
var member_edn_schema = cljs.core.nth.cljs$core$IFn$_invoke$arity$2(edn_schema,branch_index);
return deercreeklabs.lancaster.utils.child_schema(schema__$1,branch_index);
});

//# sourceMappingURL=deercreeklabs.lancaster.sub.js.map

==> talk2-0.2.7.jar: public/js/test/js/cljs-runtime/deercreeklabs.lancaster.sub.js <==
goog.provide('deercreeklabs.lancaster.sub');
deercreeklabs.lancaster.sub.path_type_STAR_ = (function deercreeklabs$lancaster$sub$path_type_STAR_(path_entry){
if((path_entry instanceof cljs.core.Keyword)){
return new cljs.core.Keyword(null,"keyword","keyword",811389747);
} else {
if(typeof path_entry === 'string'){
return new cljs.core.Keyword(null,"string","string",-1989541586);
} else {
if(cljs.core.int_QMARK_(path_entry)){
return new cljs.core.Keyword(null,"int","int",-1741416922);
} else {
return null;

}
}
}
});
deercreeklabs.lancaster.sub.__GT_matching_union_child_schema = (function deercreeklabs$lancaster$sub$__GT_matching_union_child_schema(schema__$1,edn_schema,path_entry){
var path_type = deercreeklabs.lancaster.sub.path_type_STAR_(path_entry);
var ret = cljs.core.some((function (p__50363){
var vec__50364 = p__50363;
var i = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__50364,(0),null);
var sub = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__50364,(1),null);
var avro_type = deercreeklabs.lancaster.utils.avro_type_dispatch_lt(sub);
var G__50369 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [avro_type,path_type], null);
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"record","record",-779106859),new cljs.core.Keyword(null,"keyword","keyword",811389747)], null),G__50369)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i),path_entry);
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"map","map",1371690461),new cljs.core.Keyword(null,"string","string",-1989541586)], null),G__50369)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"array","array",-2080713842),new cljs.core.Keyword(null,"int","int",-1741416922)], null),G__50369)){
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"logical-type","logical-type",-1509387615),avro_type)){
var temp__5804__auto__ = new cljs.core.Keyword(null,"k->child-edn-schema","k->child-edn-schema",-999586031).cljs$core$IFn$_invoke$arity$1(edn_schema);
if(cljs.core.truth_(temp__5804__auto__)){
var __GT_ces = temp__5804__auto__;
return deercreeklabs.lancaster.utils.child_schema(deercreeklabs.lancaster.utils.child_schema(schema__$1,i));
} else {
return null;
}
} else {
return null;
}

}
}
}
}),cljs.core.map_indexed.cljs$core$IFn$_invoke$arity$2(cljs.core.vector,edn_schema));
if(cljs.core.truth_(ret)){
return ret;
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["No matching schema in union for ","key `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(path_entry),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"schema","schema",-1582001791),schema__$1,new cljs.core.Keyword(null,"k","k",-2146297393),path_entry], null));
}
});
deercreeklabs.lancaster.sub.schema_at_path = (function deercreeklabs$lancaster$sub$schema_at_path(var_args){
var G__50379 = arguments.length;
switch (G__50379) {
case 2:
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$2 = (function (schema__$1,path){
return deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3(schema__$1,path,null);
}));

(deercreeklabs.lancaster.sub.schema_at_path.cljs$core$IFn$_invoke$arity$3 = (function (schema__$1,path,p__50386){
while(true){
var map__50387 = p__50386;
var map__50387__$1 = cljs.core.__destructure_map(map__50387);
var opts = map__50387__$1;
var branches_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__50387__$1,new cljs.core.Keyword(null,"branches?","branches?",-1426607703));
var child = cljs.core.first(path);
if(cljs.core.not(child)){
return schema__$1;
} else {
var edn_schema = new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255).cljs$core$IFn$_invoke$arity$1(schema__$1);
var child_schema = (function (){var G__50389 = deercreeklabs.lancaster.utils.avro_type_dispatch_lt(edn_schema);
var G__50389__$1 = (((G__50389 instanceof cljs.core.Keyword))?G__50389.fqn:null);
switch (G__50389__$1) {
case "record":
return deercreeklabs.lancaster.utils.child_schema(schema__$1,child);

break;
case "map":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
case "array":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
case "union":
if(cljs.core.truth_((function (){var and__5043__auto__ = branches_QMARK_;
if(cljs.core.truth_(and__5043__auto__)){
return cljs.core.int_QMARK_(child);
} else {
return and__5043__auto__;
}
})())){
return deercreeklabs.lancaster.utils.child_schema(schema__$1,child);
} else {
return deercreeklabs.lancaster.sub.__GT_matching_union_child_schema(schema__$1,edn_schema,child);
}

break;
case "logical-type":
return deercreeklabs.lancaster.utils.child_schema(schema__$1);

break;
default:
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2("Can't get schema at path for non-container type.",new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"path","path",-188191168),path], null));

}
})();
var G__50415 = child_schema;
var G__50416 = cljs.core.rest(path);
var G__50417 = opts;
schema__$1 = G__50415;
path = G__50416;
p__50386 = G__50417;
continue;
}
break;
}
}));

(deercreeklabs.lancaster.sub.schema_at_path.cljs$lang$maxFixedArity = 3);

deercreeklabs.lancaster.sub.member_schemas = (function deercreeklabs$lancaster$sub$member_schemas(schema__$1){
var map__50394 = schema__$1;
var map__50394__$1 = cljs.core.__destructure_map(map__50394);
var child_info = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__50394__$1,new cljs.core.Keyword(null,"child-info","child-info",1041367133));
var edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__50394__$1,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255));
var avro_type = deercreeklabs.lancaster.utils.get_avro_type(edn_schema);
var _ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"union","union",2142937499),avro_type))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The argument to `member-schemas` must be ","a union schema. Got type `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(avro_type),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"schema","schema",-1582001791),schema__$1,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
return cljs.core.mapv.cljs$core$IFn$_invoke$arity$2((function (sub){
if((sub instanceof cljs.core.Keyword)){
return sub.cljs$core$IFn$_invoke$arity$1(cljs.core.deref(deercreeklabs.lancaster.utils._STAR___INTERNAL__name__GT_schema));
} else {
return sub;
}
}),child_info);
});
deercreeklabs.lancaster.sub.member_schema_at_branch = (function deercreeklabs$lancaster$sub$member_schema_at_branch(schema__$1,branch_index){
var map__50399 = schema__$1;
var map__50399__$1 = cljs.core.__destructure_map(map__50399);
var edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__50399__$1,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255));
var name__GT_edn_schema = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__50399__$1,new cljs.core.Keyword(null,"name->edn-schema","name->edn-schema",-1518578869));
var avro_type = deercreeklabs.lancaster.utils.get_avro_type(edn_schema);
var _ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"union","union",2142937499),avro_type))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `schema` argument to `member-schema-at-branch` ","must be a union schema. Got type: `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(avro_type),"`."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
var ___$1 = ((cljs.core.int_QMARK_(branch_index))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `branch-index` argument to `member-schema-at-branch` ","must be an integer. Got: `",cljs.core.str.cljs$core$IFn$_invoke$arity$1(branch_index),"`."].join(''),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"branch-index","branch-index",-605664862),branch_index,new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"avro-type","avro-type",-742882766),avro_type], null))})());
var ___$2 = (((((branch_index >= cljs.core.count(edn_schema))) || ((branch_index < (0)))))?(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["The `branch-index` argument (`",cljs.core.str.cljs$core$IFn$_invoke$arity$1(branch_index),"`) ","to `member-schema-at-branch` is out of range. Length of ","union schema is ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.count(edn_schema)),"."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"edn-schema","edn-schema",477120255),edn_schema,new cljs.core.Keyword(null,"branch-index","branch-index",-605664862),branch_index], null))})():null);
var member_edn_schema = cljs.core.nth.cljs$core$IFn$_invoke$arity$2(edn_schema,branch_index);
return deercreeklabs.lancaster.utils.child_schema(schema__$1,branch_index);
});

//# sourceMappingURL=deercreeklabs.lancaster.sub.js.map
